@@ -1,14 +1,18 @@
 require_relative 'helper'
 
 describe 'Adapter' do
-  supported_by Swift::DB::Postgres, Swift::DB::Mysql do
+  supported_by Swift::DB::Postgres, Swift::DB::Mysql, Swift::DB::Sqlite3 do
     describe 'typecasting' do
       before do
         @db = Swift.db
         @db.execute %q{drop table if exists users}
-        @db.execute %q{
+        serial = case @db
+          when Swift::DB::Sqlite3 then 'integer primary key'
+          else 'serial'
+        end
+        @db.execute %Q{
           create table users(
-            id      serial,
+            id      #{serial},
             name    text,
             age     integer,
             height  float,
@@ -22,7 +26,7 @@ describe 'Adapter' do
 
       it 'query result is typecast correctly' do
         dt   = '2010-01-01 23:22:21'
-        bind = [ 1, 'jim', 32, 178.71, true, false, '2010-01-02', "#{dt}.012345+11:00" ]
+        bind = [ 1, 'jim', 32, 178.71, true, false, '2010-01-02', "#{dt}.065+11:00" ]
         @db.execute %q{insert into users values(?, ?, ?, ?, ?, ?, ?, ?)}, *bind
 
         result = @db.prepare(%q{select * from users limit 1}).execute.first
@@ -36,7 +40,7 @@ describe 'Adapter' do
         assert_kind_of Time,       result[:updated]
 
         assert_equal   dt,         result[:updated].strftime('%F %T')
-        assert_equal   12345,      result[:updated].usec if @db.kind_of?(Swift::DB::Postgres)
+        assert_equal   65000,      result[:updated].usec unless @db.kind_of?(Swift::DB::Mysql)
       end
     end
   end
